/*
   A little input demo for mode 2

   Mode 2 uses two different timers to convert samples.
   The primary timer determines the time between scans,
   and the secondary timer determines the time between
   samples in a scan.

   The time between scans is in trigval; the time
   between samples is selected by trigval1.  Conversion
   from seconds or Hz is done using the standard timer
   routines.

 */

#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>
#include <getopt.h>
#include <ctype.h>

#define N_SCANS		10
#define N_CHANS		16

int subdevice = 0;
int channels[N_CHANS] = { 0, 1, 2, 3 };
double freq = 1;
double freq1 = 1000;
int range = 0;
int aref = AREF_GROUND;
int external_trigger_number = 0;

#define N_SAMPLES	(N_CHANS*N_SCANS)

sampl_t data[N_SAMPLES];


int main(int argc, char *argv[])
{
	char *fn = NULL;
	comedi_trig it;
	int err;
	int n,m,i;
	comedi_t *dev;
	double actual_freq;
	unsigned int chan[N_CHANS];

	fn = "/dev/comedi0";

	dev = comedi_open(fn);

	it.subdev = 0;
	it.mode = 2;
	it.flags = TRIG_WAKE_EOS;
	it.n_chan = N_CHANS;
	it.chanlist = chan;
	it.data = data;
	it.n = N_SCANS;
	it.trigsrc = 0;

	/* convert the frequency into a timer value */
	comedi_get_timer(dev,subdevice,freq,&it.trigvar,&actual_freq);
	printf("primary actual frequency=%g timer value=%d\n",actual_freq,it.trigvar);

	/* convert the frequency into a timer value */
	comedi_get_timer(dev,subdevice,freq1,&it.trigvar1,&actual_freq);
	printf("secondary actual frequency=%g timer value=%d\n",actual_freq,it.trigvar1);

	/* pack the channel list */
	for(i=0;i<N_CHANS;i++){
		chan[i] = CR_PACK(i&0xf, range, aref);
	}

	if ((err = comedi_trigger(dev, &it)) < 0) {
		perror("ioctl");
		exit(1);
	}

	n=0;
	while(n<N_SAMPLES){
		if((m=read(comedi_fileno(dev),data+n,(N_SAMPLES-n)*sizeof(sampl_t)))<0){
			perror("read");
			exit(1);
		}
		n+=m/sizeof(sampl_t);
		printf("read %d bytes\n",m);
	}
#if 1
	printf("number of samples read=%d\ndata[0]=%d\ndata[1]=%d\ndata[N-1]=%d\n",
		n,data[0],data[1],data[N_SAMPLES-1]);
#endif
#if 0
	{
		int j;
		int x;
		for(j=0;j<N_CHANS;j++){
			printf("chan %d\n",j);
	for(i=0;i<N_SCANS;i++){
		x=data[N_CHANS*i+j];
		x+=0x800;
		x&=0xfff;
		printf("%d\n",x);
	}
	}}
#endif

	return 0;
}

